@@ -35,33 +35,33 @@ convertWorldTimezones <- function(nameOnly=FALSE) {
   url <- "http://efele.net/maps/tz/world/tz_world.zip"
   
   filePath <- paste(dataDir,basename(url),sep='/')
-  download.file(url,filePath)
-  unzip(filePath,exdir=dataDir)
+  utils::download.file(url,filePath)
+  utils::unzip(filePath,exdir=dataDir)
   
   # Convert shapefile into SpatialPolygonsDataFrame
   dsnPath <- paste(dataDir,'world',sep='/')
-  spDF <- convertLayer(dsn=dsnPath,layerName='tz_world')
+  SPDF <- convertLayer(dsn=dsnPath,layerName='tz_world')
   
   # Rename "TZID" to "timezone"
-  names(spDF@data) <- c('timezone')
+  names(SPDF@data) <- c('timezone')
   
   # Now get additional data from Wikipedia
   wikipediaTimezoneTable <- convertWikipediaTimezoneTable()
   
-  # Merge the additional data onto the @data slot of the spDF
-  spDF@data <- dplyr::left_join(spDF@data, wikipediaTimezoneTable)
+  # Merge the additional data onto the @data slot of the SPDF
+  SPDF@data <- dplyr::left_join(SPDF@data, wikipediaTimezoneTable)
   
   # Group polygons with the same identifier
-  spDF <- organizePolygons(spDF, uniqueID='timezone')
+  SPDF <- organizePolygons(SPDF, uniqueID='timezone')
 
   # Assign a name and save the data
-  assign(datasetName,spDF)
+  assign(datasetName,SPDF)
   save(list=c(datasetName),file=paste0(dataDir,'/',datasetName,'.RData'))  
   
   # Clean up
   unlink(filePath, force=TRUE)
   unlink(dsnPath, recursive=TRUE, force=TRUE)
   
-  invisible(datasetName)
+  return(invisible(datasetName))
 }
 
